@@ -41,7 +41,7 @@ Cells and Euclidean spaces:
 
 Elements:
     FiniteElement, MixedElement, VectorElement, TensorElement
-    ElementUnion, RestrictedElement
+    EnrichedElement, RestrictedElement
 
 Arguments:
     BasisFunction, TestFunction, TrialFunction
@@ -62,6 +62,9 @@ Indices:
     Index, indices,
     i, j, k, l, p, q, r, s
 
+Spatial coordinate:
+    x (tetrahedron.x)
+
 Scalar to tensor expression conversion:
     as_tensor, as_vector, as_matrix
 
@@ -80,7 +83,7 @@ Differential operators:
     Dx, grad, div, curl, rot, Dn
 
 Nonlinear functions:
-    abs, sign, sqrt, exp, ln, cos, sin,
+    abs, sign, sqrt, exp, ln, cos, sin, tan, acos, asin, atan
 
 Discontinuous Galerkin operators:
     jump, avg, v('+'), v('-')
@@ -98,7 +101,7 @@ Form transformations:
 
 """
 
-__version__ = "0.5.2"
+__version__ = "0.5.3"
 __authors__ = "Martin Sandve Alnes and Anders Logg"
 __copyright__ = "Copyright (C) 2008-2010 " + __authors__
 __license__  = "GNU GPL version 3 or any later version"
@@ -128,7 +131,7 @@ from ufl.geometry import Cell, Space, SpatialCoordinate, FacetNormal
 
 # Finite elements classes
 from ufl.finiteelement import FiniteElementBase, FiniteElement, \
-    MixedElement, VectorElement, TensorElement, ElementUnion, ElementRestriction
+    MixedElement, VectorElement, TensorElement, EnrichedElement, RestrictedElement
 
 # Hook to extend predefined element families
 from ufl.elementlist import register_element, show_elements #, ufl_elements
@@ -163,7 +166,7 @@ from ufl.operators import rank, shape, \
                        outer, inner, dot, cross, \
                        det, inv, cofac, \
                        transpose, tr, dev, skew, sym, \
-                       sqrt, exp, ln, cos, sin, \
+                       sqrt, exp, ln, cos, sin, tan, acos, asin, atan, \
                        eq, ne, le, ge, lt, gt, conditional, sign, \
                        variable, diff, \
                        Dx,  grad, div, curl, rot, Dn, \
@@ -183,10 +186,9 @@ from ufl.formoperators import replace, derivative, action, energy_norm, rhs, lhs
 
 # Predefined convenience objects
 from ufl.objects import vertex, interval, triangle, tetrahedron, quadrilateral, hexahedron, facet,\
-                     i, j, k, l, p, q, r, s, \
-                     R1, R2, R3, \
-                     dx, ds, dS, dE, dc
+    i, j, k, l, p, q, r, s, \
+    R1, R2, R3, \
+    dx, ds, dS, dE, dc, x
 
 # Useful constants
 from math import e, pi
-
