@@ -5,7 +5,10 @@ __authors__ = "Martin Sandve Alnes"
 __date__ = "2008-10-01"
 
 # Modified by Anders Logg, 2008-2009.
-# Last changed: 2009-12-08
+# Modified by Garth N. Wells, 2010.
+# Modified by Marie E. Rognes, 2010.
+
+# Last changed: 2010-06-22
 
 from itertools import izip
 
@@ -19,6 +22,7 @@ from ufl.argument import Argument
 from ufl.coefficient import Coefficient
 from ufl.constantvalue import Zero
 from ufl.indexed import Indexed
+from ufl.indexsum import IndexSum
 
 # Lists of all Expr classes
 from ufl.classes import ufl_classes, terminal_classes, nonterminal_classes
@@ -36,8 +40,9 @@ class PartExtracter(Transformer):
 
     def expr(self, x):
         "The default is a nonlinear operator not accepting any basis functions in its children."
+        # TODO: Other operators to implement particularly? Will see when errors here trigger...
         if any(isinstance(t, Argument) for t in traverse_terminals(x)):
-            error("Found basis function in %s, this is an invalid expression." % repr(x)) # TODO: Other operators to implement particularly? Will see when errors here trigger...
+            error("Found basis function in %s, this is an invalid expression." % repr(x))
         return (x, set())
     terminal = expr
 
@@ -107,6 +112,11 @@ class PartExtracter(Transformer):
         provides = []
         ops2 = []
         for o, o_provides in ops:
+
+            # Return zero if any factor is an indexed zero
+            if isinstance(o, Indexed) and isinstance(o._expression, Zero):
+                return (0*x, set([]))
+
             provides.extend(o_provides)
             ops2.append(o)
         n = len(provides)
@@ -120,20 +130,71 @@ class PartExtracter(Transformer):
     outer = product
     dot = product
 
+    def division(self, x, *ops):
+        # FIXME: Check logic of this function
+
+        # Get numerator and denominator
+        numerator, denominator = x.operands()
+
+        provides = []
+
+        # Visit numerator
+        numerator_x, numerator_provides = self.visit(numerator)
+        provides.extend(numerator_provides)
+
+        if isinstance(numerator_x, Zero):
+            return (0*x, set([]))
+
+        # Visit denominator
+        denominator_x, denominator_provides = self.visit(denominator)
+        provides.extend(denominator_provides)
+
+        # Check for basis function in the denominator
+        if any(isinstance(t, Argument) for t in traverse_terminals(denominator)):
+            error("Found basis function in denominator of %s , this is an invalid expression." % repr(x))
+
+        # FIXME: Should we try using 'reuse_if_possible'?
+
+        provides = set(provides)
+        return (x, provides)
+
     def linear_operator(self, x, arg):
         "A linear operator in a single argument accepting arity > 0, providing whatever basis functions its argument does."
+
         o, provides = arg
-        x = self.reuse_if_possible(x, (o,))
+        #x = self.reuse_if_possible(x, (o,)) # commented out, seems to break positive/negative restrictions
+
+        if isinstance(o, Zero):
+            return (0*x, set([]))
+
         return (x, provides)
     # TODO: List all linear operators (use subclassing to simplify stuff like this?)
+    positive_restricted = linear_operator
+    negative_restricted = linear_operator
 
     def linear_indexed_type(self, x):
+
         f, i = x.operands()
         f2, provides = self.visit(f)
         x = self.reuse_if_possible(x, f2, i)
+
+        if isinstance(x, Zero):
+            return (0*x, set([]))
+
         return (x, provides)
+
+    def indexed(self, x):
+
+        f, i = x.operands()
+        f2, provides = self.visit(f)
+        x = self.reuse_if_possible(x, f2, i)
+
+        if isinstance(x._expression, Zero):
+            return (0*x, set([]))
+
+        return (x, provides)
+
     index_sum = linear_indexed_type
-    indexed = linear_indexed_type
     component_tensor = linear_indexed_type
     spatial_derivative = linear_indexed_type
 
@@ -162,13 +223,36 @@ def compute_form_with_arity(form, arity): # TODO: Test and finish
     pe = PartExtracter(arguments)
     def _transform(e):
         e, provides = pe.visit(e)
-        #print "compute_form_with_arity:", arity, bf, e, provides
         if provides == arguments:
             return e
         return Zero()
     res = transform_integrands(form, _transform)
     return res
 
+def compute_form_arities(form):
+    """Return set of arities of terms present in form."""
+
+    def _transform(e):
+        e, provides = pe.visit(e)
+        if provides == sub_arguments:
+            return e
+        return Zero()
+
+    arities = set()
+    arguments = extract_arguments(form)
+
+    for arity in range(len(arguments)+1):
+        sub_arguments = set(arguments[:arity])
+        pe = PartExtracter(sub_arguments)
+        for itg in form.integrals():
+            integrand = _transform(itg.integrand())
+            if not integrand or isinstance(integrand, Zero):
+                continue
+            arities.add(arity)
+            break
+
+    return arities
+
 def compute_form_lhs(form):
     """Compute the left hand side of a form.
 
