@@ -4,7 +4,8 @@ __authors__ = "Martin Sandve Alnes"
 __date__ = "2008-08-19"
 
 # Modified by Anders Logg, 2009.
-# Last changed: 2009-12-08
+# Modified by Garth N. Wells, 2010.
+# Last changed: 2010-06-07
 
 from ufl.log import error, warning, debug
 from ufl.assertions import ufl_assert
@@ -13,7 +14,7 @@ from ufl.indexutils import unique_indices
 
 # All classes:
 from ufl.terminal import Terminal, Tuple
-from ufl.constantvalue import Zero, IntValue, Identity,\
+from ufl.constantvalue import ConstantValue, Zero, IntValue, Identity,\
     is_true_ufl_scalar, is_ufl_scalar
 from ufl.variable import Variable
 from ufl.coefficient import ConstantBase
@@ -23,17 +24,16 @@ from ufl.tensors import ListTensor, ComponentTensor, as_tensor, as_scalar
 from ufl.algebra import Sum, Product, Division, Power, Abs
 from ufl.tensoralgebra import Transposed, Outer, Inner, Dot, Cross, Trace, \
     Determinant, Inverse, Deviatoric, Cofactor
-from ufl.mathfunctions import MathFunction, Sqrt, Exp, Ln, Cos, Sin
+from ufl.mathfunctions import MathFunction, Sqrt, Exp, Ln, Cos, Sin, Tan, Acos, Asin, Atan
 from ufl.restriction import Restricted, PositiveRestricted, NegativeRestricted
 from ufl.differentiation import Derivative, FunctionDerivative,\
     SpatialDerivative, VariableDerivative
 from ufl.conditional import EQ, NE, LE, GE, LT, GT, Conditional
 
 # Lists of all Expr classes
-#from ufl.classes import ufl_classes, terminal_classes, nonterminal_classes
 from ufl.classes import terminal_classes
 from ufl.operators import dot, inner, outer, lt, eq, conditional, sign
-from ufl.operators import sqrt, exp, ln, cos, sin
+from ufl.operators import sqrt, exp, ln, cos, sin, tan, acos, asin, atan
 from ufl.algorithms.traversal import iter_expressions
 from ufl.algorithms.analysis import extract_type
 from ufl.algorithms.transformations import expand_compounds, Transformer, transform, transform_integrands
@@ -402,17 +402,49 @@ class ForwardAD(Transformer):
         op = fp*cos(f)
         return (o, op)
 
+    def tan(self, o, a):
+        f, fp = a
+        o = self.reuse_if_possible(o, f)
+        op = fp*2.0/(cos(2.0*f) + 1.0)
+        return (o, op)
+
+    def acos(self, o, a):
+        f, fp = a
+        o = self.reuse_if_possible(o, f)
+        op = -fp/sqrt(1.0 - f**2)
+        return (o, op)
+
+    def asin(self, o, a):
+        f, fp = a
+        o = self.reuse_if_possible(o, f)
+        op = fp/sqrt(1.0 - f**2)
+        return (o, op)
+
+    def atan(self, o, a):
+        f, fp = a
+        o = self.reuse_if_possible(o, f)
+        op = fp/(1.0 + f**2)
+        return (o, op)
+
     # --- Restrictions
 
     def positive_restricted(self, o, a):
+        # TODO: Assuming here that restriction and differentiation commutes. Is this correct?
         f, fp = a
         o = self.reuse_if_possible(o, f)
-        return (o, fp('+')) # TODO: Assuming here that restriction and differentiation commutes. Is this correct?
+        if isinstance(fp, ConstantValue):
+            return (o, fp)
+        else:
+            return (o, fp('+'))
 
     def negative_restricted(self, o, a):
+        # TODO: Assuming here that restriction and differentiation commutes. Is this correct?
         f, fp = a
         o = self.reuse_if_possible(o, f)
-        return (o, fp('-')) # TODO: Assuming here that restriction and differentiation commutes. Is this correct?
+        if isinstance(fp, ConstantValue):
+            return (o, fp)
+        else:
+            return (o, fp('-'))
 
     # --- Conditionals
 
