@@ -4,13 +4,17 @@ __authors__ = "Martin Sandve Alnes and Anders Logg"
 __date__ = "2008-03-03"
 
 # Modified by Kristian B. Oelgaard
-# Last changed: 2010-01-05
+# Modified by Marie E. Rognes (meg@simula.no) 2010
+
+# Last changed: 2010-03-22
 
 from ufl.assertions import ufl_assert
 from ufl.permutation import compute_indices
 from ufl.elementlist import ufl_elements
 from ufl.common import product, index_to_component, component_to_index, istr
 from ufl.geometry import as_cell, domain2facet
+from ufl.log import info_blue
+from ufl.log import BLUE
 
 class FiniteElementBase(object):
     "Base class for all finite elements"
@@ -84,25 +88,28 @@ class FiniteElementBase(object):
         return repr(self) == repr(other)
 
     def __add__(self, other):
-        "Add two elements, creating a mixed element"
+        "Add two elements, creating an enriched element"
         ufl_assert(isinstance(other, FiniteElementBase), "Can't add element and %s." % other.__class__)
-        return MixedElement(self, other)
+        print
+        print BLUE % "WARNING: Creating an EnrichedElement,\n         if you intended to create a MixedElement use '*' instead of '+'."
+        print
+        return EnrichedElement(self, other)
 
     def __repr__(self):
         "Format as string for evaluation as Python object."
         return self._repr
 
-    #def __mul__(self, other): # TODO: Make __mul__ -> mixed and __add__ -> union?
-    #    "Multiply two elements, creating a mixed element"
-    #    ufl_assert(isinstance(other, FiniteElementBase), "Can't multiply element and %s." % other.__class__)
-    #    return MixedElement(self, other)
+    def __mul__(self, other):
+        "Multiply two elements, creating a mixed element"
+        ufl_assert(isinstance(other, FiniteElementBase), "Can't multiply element and %s." % other.__class__)
+        return MixedElement(self, other)
 
     def __getitem__(self, index):
         "Restrict finite element to a subdomain, subcomponent or topology (cell)."
         from ufl.integral import Measure
         from ufl.geometry import Cell
         if isinstance(index, Measure) or isinstance(as_cell(index), Cell):
-            return ElementRestriction(self, index)
+            return RestrictedElement(self, index)
         #if isinstance(index, int):
         #    return SubElement(self, index)
         return NotImplemented
@@ -369,8 +376,11 @@ class TensorElement(MixedElement):
             sym = " with symmetry"
         return "Tensor<%s x %s%s>" % (self.value_shape(), self._sub_element.shortstr(), sym)
 
-class ElementUnion(FiniteElementBase):
-    "The union of two finite element spaces."
+class EnrichedElement(FiniteElementBase):
+    """The vector sum of two finite element spaces:
+
+        EnrichedElement(V, Q) = {v + q | v in V, q in Q}.
+    """
     def __init__(self, *elements):
         self._elements = elements
 
@@ -383,27 +393,27 @@ class ElementUnion(FiniteElementBase):
         ufl_assert(all(e.value_shape() == value_shape for e in elements), "Element value shape mismatch.")
 
         # Initialize element data
-        FiniteElementBase.__init__(self, "ElementUnion", cell, degree, value_shape)
+        FiniteElementBase.__init__(self, "EnrichedElement", cell, degree, value_shape)
 
         # Cache repr string
-        self._repr = "ElementUnion(%s)" % ", ".join(repr(e) for e in self._elements)
+        self._repr = "EnrichedElement(%s)" % ", ".join(repr(e) for e in self._elements)
 
     def __str__(self):
         "Format as string for pretty printing."
-        return "<%s>" % " U ".join(str(e) for e in self._elements)
+        return "<%s>" % " + ".join(str(e) for e in self._elements)
 
     def shortstr(self):
         "Format as string for pretty printing."
-        return "<%s>" % " U ".join(e.shortstr() for e in self._elements)
+        return "<%s>" % " + ".join(e.shortstr() for e in self._elements)
 
-class ElementRestriction(FiniteElementBase):
+class RestrictedElement(FiniteElementBase):
     def __init__(self, element, domain):
         ufl_assert(isinstance(element, FiniteElementBase), "Expecting a finite element instance.")
         from ufl.integral import Measure
         from ufl.geometry import Cell
         ufl_assert(isinstance(domain, Measure) or isinstance(as_cell(domain), Cell),\
             "Expecting a subdomain represented by a Measure or Cell instance.")
-        FiniteElementBase.__init__(self, "ElementRestriction", element.cell(), element.degree(), element.value_shape())
+        FiniteElementBase.__init__(self, "RestrictedElement", element.cell(), element.degree(), element.value_shape())
         self._element = element
 
         # Just attach domain if it is a Measure
@@ -417,16 +427,12 @@ class ElementRestriction(FiniteElementBase):
                 domain = Cell(domain2facet[self.cell().domain()])
             self._domain = domain
 
-        self._repr = "ElementRestriction(%r, %r)" % (element, domain)
+        self._repr = "RestrictedElement(%r, %r)" % (element, domain)
 
     def element(self):
         "Return the element which is restricted."
         return self._element
 
-    def domain(self):
-        "Return the domain onto which the element is restricted."
-        return self._domain
-
     def __str__(self):
         "Format as string for pretty printing."
         return "<%s>|_{%s}" % (self._element, self._domain)
